@@ -34,6 +34,23 @@ where
     println!("{} is Send + Sync!", std::any::type_name::<T>());
 }
 
+#[test]
+fn test_decision_making_task() {
+    fn foo<T>()
+    where
+        T: DecisionMakingTask,
+    {
+        println!("{} is DecisionMakingTask!", std::any::type_name::<T>());
+    }
+
+    foo::<Machinery>();
+    foo::<Parallelizer>();
+    foo::<Planner>();
+    foo::<Reasoner>();
+    foo::<Selector>();
+    foo::<Sequencer>();
+}
+
 #[test]
 fn test_reasoner() {
     struct Memory {
